@@ -1,5 +1,8 @@
+from .alerts import AlertsService
 from .base import BaseObject, BaseService
 from .dashboards import DashboardsService
 from .data_sources import DataSourcesService
+from .destinations import DestService
 from .mixins import *
 from .queries import QueriesService
+from .users import UsersService
